<?php

namespace Drupal\video_embed_archive\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure Video Embed Archive settings.
 */
class ArchiveForm extends ConfigFormBase {

  /**
   * The video_embed_archive configuration.
   *
   * @var array
   *
   * @see \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * Constructs the form object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    parent::__construct($config_factory);
    $this->config = $this->config('video_embed_archive.settings');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static (
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'video_embed_archive_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['video_embed_archive.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $options = [
      '0' => $this->t('No'),
      '1' => $this->t('Yes'),
    ];

    // Show Controls.
    $form['show_controls'] = [
      '#type' => 'select',
      '#title' => $this->t('Show controls.'),
      '#description' => $this->t('Show the video controls.'),
      '#default_value' => $this->config->get('show_controls'),
      '#options' => $options,
    ];

    // Hide controls.
    $form['hide_controls'] = [
      '#type' => 'select',
      '#title' => $this->t('Hide controls.'),
      '#description' => $this->t('Hide controls after mouse leaves the player window.'),
      '#default_value' => $this->config->get('hide_controls'),
      '#options' => $options,
    ];
    
    // Loop the video.
    $form['loop_video'] = [
      '#type' => 'select',
      '#title' => $this->t('Loop video.'),
      '#description' => $this->t('Loop the video.'),
      '#default_value' => $this->config->get('loop_video'),
      '#options' => $options,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $field_list = [
      'show_controls',
      'hide_controls',
      'loop_video',
    ];

    // Update the fields.
    foreach ($field_list as $field_name) {
      // Retrieve value from the form.
      $val = $form_state->getValue($field_name);

      // Add to config.
      $this->config->set($field_name, $val);
    }

    // Save the config.
    $this->config->save();
  }
}
