<?php

namespace Drupal\video_embed_archive\Plugin\video_embed_field\Provider;

use GuzzleHttp\Exception\RequestException;
use Drupal\video_embed_field\ProviderPluginBase;
use Drupal\Component\Serialization\Json;
use Drupal\Core\Url;

/**
 * An Archive.org provider plugin.
 *
 * @VideoEmbedProvider(
 *   id = "video_embed_archive",
 *   title = @Translation("Archive.org")
 * )
 */
class VideoEmbedArchive extends ProviderPluginBase {

  /**
   * {@inheritdoc}
   */
  public function renderEmbedCode($width, $height, $autoplay) {
    // Get config.
    $config = \Drupal::config('video_embed_archive.settings');

    $query = array();

    if ($autoplay) {
      $query['autoplay'] = 'true';
    }

    // Show controls.
    $show_controls = $config->get('show_controls');
    if ($show_controls == '1') {
      $query['controlbar.position'] = 'over';
    }
    else {
      $query['controlbar.position'] = 'none';
    }

    // Hide controls after mouse left the player window.
    $hide_controls = $config->get('hide_controls');
    if ($hide_controls == '1') {
      $query['controlbar.idlehide'] = 'true';
    }

    // Loop the video.
    $loop_video = $config->get('loop_video');
    if ($loop_video == '1') {
      $query['repeat'] = 'list';
    }

    $url = Url::fromUri('https://www.archive.org/embed/' . $this->getVideoId(), [
      'query' => $query,
    ]);

    $iframe = [
      '#type' => 'video_embed_iframe',
      '#provider' => 'archive',
      '#url' => $url->toString(),
      '#attributes' => [
        'width' => $width,
        'height' => $height,
        'frameborder' => '0',
        'allowfullscreen' => 'allowfullscreen',
      ],
    ];

    return $iframe;
  }

  /**
   * {@inheritdoc}
   */
  public function getRemoteThumbnailUrl() {
    return $this->oEmbedData()->thumbnail_url;
  }

  /**
   * Get the Archive.org oembed data.
   *
   * @return array
   *   An array of data from the oembed endpoint.
   */
  protected function oEmbedData() {
    $oembed_url = 'http://archive.org/embed/' . $this->getVideoId() . '&output=json';
    $data = json_decode(file_get_contents($oembed_url), TRUE);

    // Get a list of the thumbnails. The array keys are the paths.
    $files = array_keys($data['files']);

    // Simulate a real oembed response.
    $oembed = [
      'title' => $data['metadata']['title'][0],
      'thumbnail_url' => 'http://archive.org' . $files[0],
    ];

    return (object) $oembed;
  }

  /**
   * {@inheritdoc}
   */
  public static function getIdFromInput($input) {
    preg_match('@archive\.org/details/([^"\& ]+)@i', $input, $matches);
    return isset($matches[1]) ? $matches[1] : FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getName() {
    return $this->oEmbedData()->title;
  }
}
